pub struct AgentCommandSpec {
pub name: String,
pub purpose: String,
pub mutates_source: bool,
pub required_flags_for_mutation: Vec<String>,
pub primary_schema: String,
pub example: String,
}Expand description
Agent-facing command contract for safe automation.
Fields
name: Stringpurpose: Stringmutates_source: boolrequired_flags_for_mutation: Vec<String>primary_schema: Stringexample: StringTrait Implementations
Sourceimpl Clone for AgentCommandSpec
impl Clone for AgentCommandSpec
Sourcefn clone(&self) -> AgentCommandSpec
fn clone(&self) -> AgentCommandSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentCommandSpec
impl Debug for AgentCommandSpec
Sourceimpl<'de> Deserialize<'de> for AgentCommandSpec
impl<'de> Deserialize<'de> for AgentCommandSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentCommandSpec
impl JsonSchema for AgentCommandSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentCommandSpec
impl RefUnwindSafe for AgentCommandSpec
impl Send for AgentCommandSpec
impl Sync for AgentCommandSpec
impl Unpin for AgentCommandSpec
impl UnsafeUnpin for AgentCommandSpec
impl UnwindSafe for AgentCommandSpec