pub struct AgentPack {
pub schema_version: String,
pub target_agent: String,
pub files: Vec<AgentPackFile>,
pub install_note: String,
}Expand description
Agent runtime manifest and pack records for external coding agents.
Fields
schema_version: Stringtarget_agent: Stringfiles: Vec<AgentPackFile>install_note: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for AgentPack
impl<'de> Deserialize<'de> for AgentPack
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentPack
impl JsonSchema for AgentPack
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentPack
impl RefUnwindSafe for AgentPack
impl Send for AgentPack
impl Sync for AgentPack
impl Unpin for AgentPack
impl UnsafeUnpin for AgentPack
impl UnwindSafe for AgentPack