pub struct AgentPackFile {
pub path: String,
pub purpose: String,
pub content: String,
}Expand description
Agent runtime manifest and pack records for external coding agents.
Fields
path: Stringpurpose: Stringcontent: StringTrait Implementations
Sourceimpl Clone for AgentPackFile
impl Clone for AgentPackFile
Sourcefn clone(&self) -> AgentPackFile
fn clone(&self) -> AgentPackFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentPackFile
impl Debug for AgentPackFile
Sourceimpl<'de> Deserialize<'de> for AgentPackFile
impl<'de> Deserialize<'de> for AgentPackFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentPackFile
impl JsonSchema for AgentPackFile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentPackFile
impl RefUnwindSafe for AgentPackFile
impl Send for AgentPackFile
impl Sync for AgentPackFile
impl Unpin for AgentPackFile
impl UnsafeUnpin for AgentPackFile
impl UnwindSafe for AgentPackFile