pub struct AgentReadyContractRefs {
pub discovery: String,
pub runtime: String,
pub scorecard_artifact: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable during the v1 beta.
Fields
discovery: Stringruntime: Stringscorecard_artifact: Option<String>Trait Implementations
Sourceimpl Clone for AgentReadyContractRefs
impl Clone for AgentReadyContractRefs
Sourcefn clone(&self) -> AgentReadyContractRefs
fn clone(&self) -> AgentReadyContractRefs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentReadyContractRefs
impl Debug for AgentReadyContractRefs
Sourceimpl<'de> Deserialize<'de> for AgentReadyContractRefs
impl<'de> Deserialize<'de> for AgentReadyContractRefs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentReadyContractRefs
impl JsonSchema for AgentReadyContractRefs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentReadyContractRefs
impl RefUnwindSafe for AgentReadyContractRefs
impl Send for AgentReadyContractRefs
impl Sync for AgentReadyContractRefs
impl Unpin for AgentReadyContractRefs
impl UnsafeUnpin for AgentReadyContractRefs
impl UnwindSafe for AgentReadyContractRefs