pub struct AgentRunResult {
pub output: Value,
pub duration_ms: u64,
pub success: bool,
pub error: Option<String>,
pub traces: Vec<TraceEvent>,
}Expand description
Agent runner result and trace events. These are unstable before 1.0.
The result of running an agent on a single input, including traces.
Fields
output: Valueduration_ms: u64success: boolerror: Option<String>traces: Vec<TraceEvent>Trait Implementations
Sourceimpl Clone for AgentRunResult
impl Clone for AgentRunResult
Sourcefn clone(&self) -> AgentRunResult
fn clone(&self) -> AgentRunResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentRunResult
impl Debug for AgentRunResult
Sourceimpl<'de> Deserialize<'de> for AgentRunResult
impl<'de> Deserialize<'de> for AgentRunResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentRunResult
impl JsonSchema for AgentRunResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentRunResult
impl RefUnwindSafe for AgentRunResult
impl Send for AgentRunResult
impl Sync for AgentRunResult
impl Unpin for AgentRunResult
impl UnsafeUnpin for AgentRunResult
impl UnwindSafe for AgentRunResult