pub struct AgentRuntimeManifest {
pub schema_version: String,
pub product_version: String,
pub transports: Vec<AgentRuntimeTransport>,
pub tools: Vec<AgentRuntimeTool>,
pub mutation_rules: Vec<String>,
}Expand description
Agent runtime manifest and pack records for external coding agents.
Fields
schema_version: Stringproduct_version: Stringtransports: Vec<AgentRuntimeTransport>tools: Vec<AgentRuntimeTool>mutation_rules: Vec<String>Trait Implementations
Sourceimpl Clone for AgentRuntimeManifest
impl Clone for AgentRuntimeManifest
Sourcefn clone(&self) -> AgentRuntimeManifest
fn clone(&self) -> AgentRuntimeManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentRuntimeManifest
impl Debug for AgentRuntimeManifest
Sourceimpl<'de> Deserialize<'de> for AgentRuntimeManifest
impl<'de> Deserialize<'de> for AgentRuntimeManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentRuntimeManifest
impl JsonSchema for AgentRuntimeManifest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentRuntimeManifest
impl RefUnwindSafe for AgentRuntimeManifest
impl Send for AgentRuntimeManifest
impl Sync for AgentRuntimeManifest
impl Unpin for AgentRuntimeManifest
impl UnsafeUnpin for AgentRuntimeManifest
impl UnwindSafe for AgentRuntimeManifest