pub struct AgentRuntimeTool {
pub name: String,
pub description: String,
pub read_only: bool,
pub mutation_capable: bool,
pub required_flags_for_mutation: Vec<String>,
pub request_schema: String,
pub response_schema: String,
}Expand description
Agent runtime manifest and pack records for external coding agents.
Fields
name: Stringdescription: Stringread_only: boolmutation_capable: boolrequired_flags_for_mutation: Vec<String>request_schema: Stringresponse_schema: StringTrait Implementations
Sourceimpl Clone for AgentRuntimeTool
impl Clone for AgentRuntimeTool
Sourcefn clone(&self) -> AgentRuntimeTool
fn clone(&self) -> AgentRuntimeTool
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentRuntimeTool
impl Debug for AgentRuntimeTool
Sourceimpl<'de> Deserialize<'de> for AgentRuntimeTool
impl<'de> Deserialize<'de> for AgentRuntimeTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentRuntimeTool
impl JsonSchema for AgentRuntimeTool
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentRuntimeTool
impl RefUnwindSafe for AgentRuntimeTool
impl Send for AgentRuntimeTool
impl Sync for AgentRuntimeTool
impl Unpin for AgentRuntimeTool
impl UnsafeUnpin for AgentRuntimeTool
impl UnwindSafe for AgentRuntimeTool