pub struct AgentRuntimeTransport {
pub id: String,
pub command: String,
pub description: String,
}Expand description
Agent runtime manifest and pack records for external coding agents.
Fields
id: Stringcommand: Stringdescription: StringTrait Implementations
Sourceimpl Clone for AgentRuntimeTransport
impl Clone for AgentRuntimeTransport
Sourcefn clone(&self) -> AgentRuntimeTransport
fn clone(&self) -> AgentRuntimeTransport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentRuntimeTransport
impl Debug for AgentRuntimeTransport
Sourceimpl<'de> Deserialize<'de> for AgentRuntimeTransport
impl<'de> Deserialize<'de> for AgentRuntimeTransport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentRuntimeTransport
impl JsonSchema for AgentRuntimeTransport
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentRuntimeTransport
impl RefUnwindSafe for AgentRuntimeTransport
impl Send for AgentRuntimeTransport
impl Sync for AgentRuntimeTransport
impl Unpin for AgentRuntimeTransport
impl UnsafeUnpin for AgentRuntimeTransport
impl UnwindSafe for AgentRuntimeTransport