pub struct AgentWorkflow {
pub id: String,
pub goal: String,
pub steps: Vec<String>,
}Expand description
Agent-facing command contract for safe automation.
Fields
id: Stringgoal: Stringsteps: Vec<String>Trait Implementations
Sourceimpl Clone for AgentWorkflow
impl Clone for AgentWorkflow
Sourcefn clone(&self) -> AgentWorkflow
fn clone(&self) -> AgentWorkflow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentWorkflow
impl Debug for AgentWorkflow
Sourceimpl<'de> Deserialize<'de> for AgentWorkflow
impl<'de> Deserialize<'de> for AgentWorkflow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentWorkflow
impl JsonSchema for AgentWorkflow
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentWorkflow
impl RefUnwindSafe for AgentWorkflow
impl Send for AgentWorkflow
impl Sync for AgentWorkflow
impl Unpin for AgentWorkflow
impl UnsafeUnpin for AgentWorkflow
impl UnwindSafe for AgentWorkflow