pub struct ArtifactExplanation {
pub schema_version: String,
pub artifact_path: String,
pub artifact_kind: ArtifactKind,
pub summary: String,
pub mutates_source: bool,
pub recommended_next_actions: Vec<String>,
}Expand description
Agent-facing artifact explanation helpers.
Fields
schema_version: Stringartifact_path: Stringartifact_kind: ArtifactKindsummary: Stringmutates_source: boolrecommended_next_actions: Vec<String>Trait Implementations
Sourceimpl Clone for ArtifactExplanation
impl Clone for ArtifactExplanation
Sourcefn clone(&self) -> ArtifactExplanation
fn clone(&self) -> ArtifactExplanation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactExplanation
impl Debug for ArtifactExplanation
Sourceimpl<'de> Deserialize<'de> for ArtifactExplanation
impl<'de> Deserialize<'de> for ArtifactExplanation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArtifactExplanation
impl JsonSchema for ArtifactExplanation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ArtifactExplanation
impl RefUnwindSafe for ArtifactExplanation
impl Send for ArtifactExplanation
impl Sync for ArtifactExplanation
impl Unpin for ArtifactExplanation
impl UnsafeUnpin for ArtifactExplanation
impl UnwindSafe for ArtifactExplanation