pub struct AuditFinding {
pub id: String,
pub severity: AuditSeverity,
pub title: String,
pub description: String,
pub file: Option<String>,
pub line: Option<usize>,
}Expand description
Deterministic static audit reports.
Fields
id: Stringseverity: AuditSeveritytitle: Stringdescription: Stringfile: Option<String>line: Option<usize>Trait Implementations
Sourceimpl Clone for AuditFinding
impl Clone for AuditFinding
Sourcefn clone(&self) -> AuditFinding
fn clone(&self) -> AuditFinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuditFinding
impl Debug for AuditFinding
Sourceimpl<'de> Deserialize<'de> for AuditFinding
impl<'de> Deserialize<'de> for AuditFinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuditFinding
impl JsonSchema for AuditFinding
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuditFinding
impl RefUnwindSafe for AuditFinding
impl Send for AuditFinding
impl Sync for AuditFinding
impl Unpin for AuditFinding
impl UnsafeUnpin for AuditFinding
impl UnwindSafe for AuditFinding