pub struct AuditProvenance {
pub git_sha_before: Option<String>,
pub git_sha_after: Option<String>,
pub working_tree_dirty_after: Option<bool>,
pub policy_path: Option<String>,
pub policy_hash: Option<String>,
pub dataset_version: String,
pub dataset_hash: String,
pub scorer_id: String,
pub scorer_version: String,
pub model: ModelProvenance,
}Expand description
Optimizer entrypoint and run records. These are unstable before 1.0.
Provenance fields that identify what inputs and tools produced the change.
Fields
git_sha_before: Option<String>git_sha_after: Option<String>working_tree_dirty_after: Option<bool>policy_path: Option<String>policy_hash: Option<String>dataset_version: Stringdataset_hash: Stringscorer_id: Stringscorer_version: Stringmodel: ModelProvenanceTrait Implementations
Sourceimpl Clone for AuditProvenance
impl Clone for AuditProvenance
Sourcefn clone(&self) -> AuditProvenance
fn clone(&self) -> AuditProvenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuditProvenance
impl Debug for AuditProvenance
Sourceimpl<'de> Deserialize<'de> for AuditProvenance
impl<'de> Deserialize<'de> for AuditProvenance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AuditProvenance
impl JsonSchema for AuditProvenance
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuditProvenance
impl RefUnwindSafe for AuditProvenance
impl Send for AuditProvenance
impl Sync for AuditProvenance
impl Unpin for AuditProvenance
impl UnsafeUnpin for AuditProvenance
impl UnwindSafe for AuditProvenance