pub struct AutonomyReadiness {
pub grade: AutonomyReadinessGrade,
pub max_safe_tier: RecipeTier,
pub executable_candidates: usize,
pub review_only_candidates: usize,
pub blocked_candidates: usize,
pub blockers: Vec<String>,
pub recommended_command: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
grade: AutonomyReadinessGrademax_safe_tier: RecipeTierexecutable_candidates: usizereview_only_candidates: usizeblocked_candidates: usizeblockers: Vec<String>recommended_command: Option<String>Trait Implementations
Sourceimpl Clone for AutonomyReadiness
impl Clone for AutonomyReadiness
Sourcefn clone(&self) -> AutonomyReadiness
fn clone(&self) -> AutonomyReadiness
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutonomyReadiness
impl Debug for AutonomyReadiness
Sourceimpl Default for AutonomyReadiness
impl Default for AutonomyReadiness
Sourceimpl<'de> Deserialize<'de> for AutonomyReadiness
impl<'de> Deserialize<'de> for AutonomyReadiness
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutonomyReadiness
impl JsonSchema for AutonomyReadiness
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AutonomyReadiness
impl RefUnwindSafe for AutonomyReadiness
impl Send for AutonomyReadiness
impl Sync for AutonomyReadiness
impl Unpin for AutonomyReadiness
impl UnsafeUnpin for AutonomyReadiness
impl UnwindSafe for AutonomyReadiness