pub struct AutopilotPass {
pub pass_index: usize,
pub plan_id: String,
pub plan_hash: String,
pub plan_artifact_path: Option<String>,
pub planned_candidates: usize,
pub executable_candidates: usize,
pub batch: Option<RefactorBatchApplyRun>,
pub status: AutopilotPassStatus,
pub note: String,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
pass_index: usizeplan_id: Stringplan_hash: Stringplan_artifact_path: Option<String>planned_candidates: usizeexecutable_candidates: usizebatch: Option<RefactorBatchApplyRun>status: AutopilotPassStatusnote: StringTrait Implementations
Sourceimpl Clone for AutopilotPass
impl Clone for AutopilotPass
Sourcefn clone(&self) -> AutopilotPass
fn clone(&self) -> AutopilotPass
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutopilotPass
impl Debug for AutopilotPass
Sourceimpl<'de> Deserialize<'de> for AutopilotPass
impl<'de> Deserialize<'de> for AutopilotPass
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutopilotPass
impl JsonSchema for AutopilotPass
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AutopilotPass
impl RefUnwindSafe for AutopilotPass
impl Send for AutopilotPass
impl Sync for AutopilotPass
impl Unpin for AutopilotPass
impl UnsafeUnpin for AutopilotPass
impl UnwindSafe for AutopilotPass