pub struct AutopilotRun {Show 21 fields
pub schema_version: String,
pub run_id: String,
pub root: String,
pub target: Option<String>,
pub mode: RefactorApplyMode,
pub status: AutopilotStatus,
pub budget_seconds: Option<u64>,
pub max_passes: usize,
pub max_candidates_per_pass: usize,
pub quality_before: CodebaseQualitySummary,
pub quality_after: Option<CodebaseQualitySummary>,
pub evidence: EvidenceSummary,
pub measured_evidence: Option<EvidenceArtifactRef>,
pub execution_summary: AutopilotExecutionSummary,
pub passes: Vec<AutopilotPass>,
pub total_planned_candidates: usize,
pub total_executed_candidates: usize,
pub total_skipped_candidates: usize,
pub budget_exhausted: bool,
pub note: String,
pub artifact_path: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
schema_version: Stringrun_id: Stringroot: Stringtarget: Option<String>mode: RefactorApplyModestatus: AutopilotStatusbudget_seconds: Option<u64>max_passes: usizemax_candidates_per_pass: usizequality_before: CodebaseQualitySummaryquality_after: Option<CodebaseQualitySummary>evidence: EvidenceSummarymeasured_evidence: Option<EvidenceArtifactRef>execution_summary: AutopilotExecutionSummarypasses: Vec<AutopilotPass>total_planned_candidates: usizetotal_executed_candidates: usizetotal_skipped_candidates: usizebudget_exhausted: boolnote: Stringartifact_path: Option<String>Trait Implementations
Sourceimpl Clone for AutopilotRun
impl Clone for AutopilotRun
Sourcefn clone(&self) -> AutopilotRun
fn clone(&self) -> AutopilotRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutopilotRun
impl Debug for AutopilotRun
Sourceimpl<'de> Deserialize<'de> for AutopilotRun
impl<'de> Deserialize<'de> for AutopilotRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutopilotRun
impl JsonSchema for AutopilotRun
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AutopilotRun
impl RefUnwindSafe for AutopilotRun
impl Send for AutopilotRun
impl Sync for AutopilotRun
impl Unpin for AutopilotRun
impl UnsafeUnpin for AutopilotRun
impl UnwindSafe for AutopilotRun