pub struct BehaviorCommand {
pub id: String,
pub command: String,
pub args: Vec<String>,
pub cwd: Option<String>,
pub expect_success: bool,
pub expect_stdout_contains: Vec<String>,
pub expect_stderr_contains: Vec<String>,
pub timeout_seconds: Option<u64>,
}Expand description
Dataset and scorer metadata used by optimizer reports.
Fields
id: Stringcommand: Stringargs: Vec<String>cwd: Option<String>expect_success: boolexpect_stdout_contains: Vec<String>expect_stderr_contains: Vec<String>timeout_seconds: Option<u64>Trait Implementations
Sourceimpl Clone for BehaviorCommand
impl Clone for BehaviorCommand
Sourcefn clone(&self) -> BehaviorCommand
fn clone(&self) -> BehaviorCommand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BehaviorCommand
impl Debug for BehaviorCommand
Sourceimpl<'de> Deserialize<'de> for BehaviorCommand
impl<'de> Deserialize<'de> for BehaviorCommand
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BehaviorCommand
impl JsonSchema for BehaviorCommand
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BehaviorCommand
impl RefUnwindSafe for BehaviorCommand
impl Send for BehaviorCommand
impl Sync for BehaviorCommand
impl Unpin for BehaviorCommand
impl UnsafeUnpin for BehaviorCommand
impl UnwindSafe for BehaviorCommand