pub struct BehaviorCommandRecord {
pub id: String,
pub command: String,
pub success: bool,
pub timed_out: bool,
pub status_code: Option<i32>,
pub duration_ms: u64,
pub stdout: String,
pub stderr: String,
pub failure_reason: Option<String>,
}Expand description
Dataset and scorer metadata used by optimizer reports.
Fields
id: Stringcommand: Stringsuccess: booltimed_out: boolstatus_code: Option<i32>duration_ms: u64stdout: Stringstderr: Stringfailure_reason: Option<String>Trait Implementations
Sourceimpl Clone for BehaviorCommandRecord
impl Clone for BehaviorCommandRecord
Sourcefn clone(&self) -> BehaviorCommandRecord
fn clone(&self) -> BehaviorCommandRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BehaviorCommandRecord
impl Debug for BehaviorCommandRecord
Sourceimpl<'de> Deserialize<'de> for BehaviorCommandRecord
impl<'de> Deserialize<'de> for BehaviorCommandRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BehaviorCommandRecord
impl JsonSchema for BehaviorCommandRecord
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BehaviorCommandRecord
impl RefUnwindSafe for BehaviorCommandRecord
impl Send for BehaviorCommandRecord
impl Sync for BehaviorCommandRecord
impl Unpin for BehaviorCommandRecord
impl UnsafeUnpin for BehaviorCommandRecord
impl UnwindSafe for BehaviorCommandRecord