pub struct BehaviorEvalSpec {
pub version: String,
pub commands: Vec<BehaviorCommand>,
}Expand description
Dataset and scorer metadata used by optimizer reports.
Fields
version: Stringcommands: Vec<BehaviorCommand>Trait Implementations
Sourceimpl Clone for BehaviorEvalSpec
impl Clone for BehaviorEvalSpec
Sourcefn clone(&self) -> BehaviorEvalSpec
fn clone(&self) -> BehaviorEvalSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BehaviorEvalSpec
impl Debug for BehaviorEvalSpec
Sourceimpl<'de> Deserialize<'de> for BehaviorEvalSpec
impl<'de> Deserialize<'de> for BehaviorEvalSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BehaviorEvalSpec
impl JsonSchema for BehaviorEvalSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BehaviorEvalSpec
impl RefUnwindSafe for BehaviorEvalSpec
impl Send for BehaviorEvalSpec
impl Sync for BehaviorEvalSpec
impl Unpin for BehaviorEvalSpec
impl UnsafeUnpin for BehaviorEvalSpec
impl UnwindSafe for BehaviorEvalSpec