pub struct Candidate {
pub focus: String,
pub description: String,
pub expected_improvement: String,
pub strategy: Option<EditStrategy>,
}Expand description
Optimizer entrypoint and run records. These are unstable before 1.0.
A proposed improvement generated during an optimization iteration.
Fields
focus: Stringdescription: Stringexpected_improvement: Stringstrategy: Option<EditStrategy>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Candidate
impl<'de> Deserialize<'de> for Candidate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Candidate
impl JsonSchema for Candidate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Candidate
impl RefUnwindSafe for Candidate
impl Send for Candidate
impl Sync for Candidate
impl Unpin for Candidate
impl UnsafeUnpin for Candidate
impl UnwindSafe for Candidate