pub struct CandidateAutonomyDecision {
pub decision: AutonomyDecision,
pub reasons: Vec<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
decision: AutonomyDecisionreasons: Vec<String>Trait Implementations
Sourceimpl Clone for CandidateAutonomyDecision
impl Clone for CandidateAutonomyDecision
Sourcefn clone(&self) -> CandidateAutonomyDecision
fn clone(&self) -> CandidateAutonomyDecision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CandidateAutonomyDecision
impl Debug for CandidateAutonomyDecision
Sourceimpl Default for CandidateAutonomyDecision
impl Default for CandidateAutonomyDecision
Sourceimpl<'de> Deserialize<'de> for CandidateAutonomyDecision
impl<'de> Deserialize<'de> for CandidateAutonomyDecision
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CandidateAutonomyDecision
impl JsonSchema for CandidateAutonomyDecision
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CandidateAutonomyDecision
impl RefUnwindSafe for CandidateAutonomyDecision
impl Send for CandidateAutonomyDecision
impl Sync for CandidateAutonomyDecision
impl Unpin for CandidateAutonomyDecision
impl UnsafeUnpin for CandidateAutonomyDecision
impl UnwindSafe for CandidateAutonomyDecision