pub struct CandidateExecutionOutcome {Show 15 fields
pub validated: u32,
pub landed: u32,
pub accepted: u32,
pub accepted_diff: Option<String>,
pub patched_score: Option<f32>,
pub holdout_score: Option<f32>,
pub delta: Option<f32>,
pub note: String,
pub hook_decisions: Vec<HookDecision>,
pub validation_commands: Vec<ValidationCommandRecord>,
pub final_validation_commands: Vec<ValidationCommandRecord>,
pub rollback_succeeded: Option<bool>,
pub rollback_error: Option<String>,
pub timed_out: bool,
pub rejection: Option<SafetyRejection>,
}Expand description
Candidate safety pipeline. Direct use is unstable before 1.0.
Fields
validated: u32landed: u32accepted: u32accepted_diff: Option<String>patched_score: Option<f32>holdout_score: Option<f32>delta: Option<f32>note: Stringhook_decisions: Vec<HookDecision>validation_commands: Vec<ValidationCommandRecord>final_validation_commands: Vec<ValidationCommandRecord>rollback_succeeded: Option<bool>rollback_error: Option<String>timed_out: boolrejection: Option<SafetyRejection>Trait Implementations
Sourceimpl Clone for CandidateExecutionOutcome
impl Clone for CandidateExecutionOutcome
Sourcefn clone(&self) -> CandidateExecutionOutcome
fn clone(&self) -> CandidateExecutionOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CandidateExecutionOutcome
impl Debug for CandidateExecutionOutcome
Sourceimpl<'de> Deserialize<'de> for CandidateExecutionOutcome
impl<'de> Deserialize<'de> for CandidateExecutionOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CandidateExecutionOutcome
impl JsonSchema for CandidateExecutionOutcome
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CandidateExecutionOutcome
impl RefUnwindSafe for CandidateExecutionOutcome
impl Send for CandidateExecutionOutcome
impl Sync for CandidateExecutionOutcome
impl Unpin for CandidateExecutionOutcome
impl UnsafeUnpin for CandidateExecutionOutcome
impl UnwindSafe for CandidateExecutionOutcome