pub struct CodebaseMap {Show 17 fields
pub schema_version: String,
pub map_id: String,
pub map_hash: String,
pub root: String,
pub target: Option<String>,
pub workspace: WorkspaceSummary,
pub policy: Option<ProjectPolicy>,
pub behavior_spec: Option<String>,
pub evidence: EvidenceSummary,
pub quality: CodebaseQualitySummary,
pub capability_gates: Vec<CapabilityGate>,
pub impact: RefactorImpactSummary,
pub files: Vec<RefactorFileSummary>,
pub module_edges: Vec<ModuleEdge>,
pub findings: Vec<HardeningFinding>,
pub recommended_actions: Vec<String>,
pub artifact_path: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
schema_version: Stringmap_id: Stringmap_hash: Stringroot: Stringtarget: Option<String>workspace: WorkspaceSummarypolicy: Option<ProjectPolicy>behavior_spec: Option<String>evidence: EvidenceSummaryquality: CodebaseQualitySummarycapability_gates: Vec<CapabilityGate>impact: RefactorImpactSummaryfiles: Vec<RefactorFileSummary>module_edges: Vec<ModuleEdge>findings: Vec<HardeningFinding>recommended_actions: Vec<String>artifact_path: Option<String>Trait Implementations
Sourceimpl Clone for CodebaseMap
impl Clone for CodebaseMap
Sourcefn clone(&self) -> CodebaseMap
fn clone(&self) -> CodebaseMap
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodebaseMap
impl Debug for CodebaseMap
Sourceimpl<'de> Deserialize<'de> for CodebaseMap
impl<'de> Deserialize<'de> for CodebaseMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CodebaseMap
impl JsonSchema for CodebaseMap
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CodebaseMap
impl RefUnwindSafe for CodebaseMap
impl Send for CodebaseMap
impl Sync for CodebaseMap
impl Unpin for CodebaseMap
impl UnsafeUnpin for CodebaseMap
impl UnwindSafe for CodebaseMap