pub struct CodebaseQualitySummary {
pub grade: CodebaseQualityGrade,
pub debt_score: u8,
pub security_score: u8,
pub patchable_findings: usize,
pub review_only_findings: usize,
pub public_api_pressure: usize,
pub oversized_files: usize,
pub oversized_functions: usize,
pub test_coverage_signal: TestCoverageSignal,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
grade: CodebaseQualityGradedebt_score: u8security_score: u8patchable_findings: usizereview_only_findings: usizepublic_api_pressure: usizeoversized_files: usizeoversized_functions: usizetest_coverage_signal: TestCoverageSignalTrait Implementations
Sourceimpl Clone for CodebaseQualitySummary
impl Clone for CodebaseQualitySummary
Sourcefn clone(&self) -> CodebaseQualitySummary
fn clone(&self) -> CodebaseQualitySummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodebaseQualitySummary
impl Debug for CodebaseQualitySummary
Sourceimpl<'de> Deserialize<'de> for CodebaseQualitySummary
impl<'de> Deserialize<'de> for CodebaseQualitySummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CodebaseQualitySummary
impl JsonSchema for CodebaseQualitySummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CodebaseQualitySummary
impl RefUnwindSafe for CodebaseQualitySummary
impl Send for CodebaseQualitySummary
impl Sync for CodebaseQualitySummary
impl Unpin for CodebaseQualitySummary
impl UnsafeUnpin for CodebaseQualitySummary
impl UnwindSafe for CodebaseQualitySummary