pub struct DatasetSplit {
pub train: Vec<EvaluationSample>,
pub holdout: Vec<EvaluationSample>,
pub holdout_percent: usize,
}Expand description
Experiment budget and ledger records. These are unstable during the v1 beta.
Fields
train: Vec<EvaluationSample>holdout: Vec<EvaluationSample>holdout_percent: usizeTrait Implementations
Sourceimpl Clone for DatasetSplit
impl Clone for DatasetSplit
Sourcefn clone(&self) -> DatasetSplit
fn clone(&self) -> DatasetSplit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatasetSplit
impl Debug for DatasetSplit
Sourceimpl<'de> Deserialize<'de> for DatasetSplit
impl<'de> Deserialize<'de> for DatasetSplit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DatasetSplit
impl JsonSchema for DatasetSplit
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DatasetSplit
impl RefUnwindSafe for DatasetSplit
impl Send for DatasetSplit
impl Sync for DatasetSplit
impl Unpin for DatasetSplit
impl UnsafeUnpin for DatasetSplit
impl UnwindSafe for DatasetSplit