pub struct EvaluationSample {
pub id: String,
pub input: Value,
}Expand description
Dataset and scorer metadata used by optimizer reports.
Fields
id: Stringinput: ValueTrait Implementations
Sourceimpl Clone for EvaluationSample
impl Clone for EvaluationSample
Sourcefn clone(&self) -> EvaluationSample
fn clone(&self) -> EvaluationSample
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvaluationSample
impl Debug for EvaluationSample
Sourceimpl<'de> Deserialize<'de> for EvaluationSample
impl<'de> Deserialize<'de> for EvaluationSample
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvaluationSample
impl JsonSchema for EvaluationSample
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvaluationSample
impl RefUnwindSafe for EvaluationSample
impl Send for EvaluationSample
impl Sync for EvaluationSample
impl Unpin for EvaluationSample
impl UnsafeUnpin for EvaluationSample
impl UnwindSafe for EvaluationSample