pub struct EvidenceCommandRecord {
pub id: String,
pub command: String,
pub skipped: bool,
pub skip_reason: Option<String>,
pub success: bool,
pub timed_out: bool,
pub status_code: Option<i32>,
pub duration_ms: u128,
pub stdout: String,
pub stderr: String,
}Expand description
Measured evidence artifacts used to gate autonomy. Unstable during the v1 beta.
Fields
id: Stringcommand: Stringskipped: boolskip_reason: Option<String>success: booltimed_out: boolstatus_code: Option<i32>duration_ms: u128stdout: Stringstderr: StringTrait Implementations
Sourceimpl Clone for EvidenceCommandRecord
impl Clone for EvidenceCommandRecord
Sourcefn clone(&self) -> EvidenceCommandRecord
fn clone(&self) -> EvidenceCommandRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvidenceCommandRecord
impl Debug for EvidenceCommandRecord
Sourceimpl<'de> Deserialize<'de> for EvidenceCommandRecord
impl<'de> Deserialize<'de> for EvidenceCommandRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvidenceCommandRecord
impl JsonSchema for EvidenceCommandRecord
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvidenceCommandRecord
impl RefUnwindSafe for EvidenceCommandRecord
impl Send for EvidenceCommandRecord
impl Sync for EvidenceCommandRecord
impl Unpin for EvidenceCommandRecord
impl UnsafeUnpin for EvidenceCommandRecord
impl UnwindSafe for EvidenceCommandRecord