pub struct EvidenceFileProfile {
pub file: String,
pub grade: EvidenceGrade,
pub analysis_depth: EvidenceAnalysisDepth,
pub signals: Vec<String>,
pub coverage_percent: Option<f64>,
pub mutation_score_percent: Option<f64>,
pub function_profiles: Vec<EvidenceFunctionProfile>,
}Expand description
Measured evidence artifacts used to gate autonomy. Unstable before 1.0.
Fields
file: Stringgrade: EvidenceGradeanalysis_depth: EvidenceAnalysisDepthsignals: Vec<String>coverage_percent: Option<f64>mutation_score_percent: Option<f64>function_profiles: Vec<EvidenceFunctionProfile>Trait Implementations
Sourceimpl Clone for EvidenceFileProfile
impl Clone for EvidenceFileProfile
Sourcefn clone(&self) -> EvidenceFileProfile
fn clone(&self) -> EvidenceFileProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvidenceFileProfile
impl Debug for EvidenceFileProfile
Sourceimpl<'de> Deserialize<'de> for EvidenceFileProfile
impl<'de> Deserialize<'de> for EvidenceFileProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvidenceFileProfile
impl JsonSchema for EvidenceFileProfile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvidenceFileProfile
impl RefUnwindSafe for EvidenceFileProfile
impl Send for EvidenceFileProfile
impl Sync for EvidenceFileProfile
impl Unpin for EvidenceFileProfile
impl UnsafeUnpin for EvidenceFileProfile
impl UnwindSafe for EvidenceFileProfile