pub struct EvidenceFunctionProfile {
pub name: String,
pub line: usize,
pub grade: EvidenceGrade,
pub signals: Vec<String>,
pub coverage_percent: Option<f64>,
}Expand description
Measured evidence artifacts used to gate autonomy. Unstable during the v1 beta.
Fields
name: Stringline: usizegrade: EvidenceGradesignals: Vec<String>coverage_percent: Option<f64>Trait Implementations
Sourceimpl Clone for EvidenceFunctionProfile
impl Clone for EvidenceFunctionProfile
Sourcefn clone(&self) -> EvidenceFunctionProfile
fn clone(&self) -> EvidenceFunctionProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvidenceFunctionProfile
impl Debug for EvidenceFunctionProfile
Sourceimpl<'de> Deserialize<'de> for EvidenceFunctionProfile
impl<'de> Deserialize<'de> for EvidenceFunctionProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvidenceFunctionProfile
impl JsonSchema for EvidenceFunctionProfile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvidenceFunctionProfile
impl RefUnwindSafe for EvidenceFunctionProfile
impl Send for EvidenceFunctionProfile
impl Sync for EvidenceFunctionProfile
impl Unpin for EvidenceFunctionProfile
impl UnsafeUnpin for EvidenceFunctionProfile
impl UnwindSafe for EvidenceFunctionProfile