pub struct EvidenceMetric {
pub id: String,
pub label: String,
pub value: f64,
pub unit: String,
pub source_command: String,
}Expand description
Measured evidence artifacts used to gate autonomy. Unstable before 1.0.
Fields
id: Stringlabel: Stringvalue: f64unit: Stringsource_command: StringTrait Implementations
Sourceimpl Clone for EvidenceMetric
impl Clone for EvidenceMetric
Sourcefn clone(&self) -> EvidenceMetric
fn clone(&self) -> EvidenceMetric
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvidenceMetric
impl Debug for EvidenceMetric
Sourceimpl<'de> Deserialize<'de> for EvidenceMetric
impl<'de> Deserialize<'de> for EvidenceMetric
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvidenceMetric
impl JsonSchema for EvidenceMetric
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvidenceMetric
impl RefUnwindSafe for EvidenceMetric
impl Send for EvidenceMetric
impl Sync for EvidenceMetric
impl Unpin for EvidenceMetric
impl UnsafeUnpin for EvidenceMetric
impl UnwindSafe for EvidenceMetric