pub struct EvidenceSummary {
pub grade: EvidenceGrade,
pub max_autonomous_tier: u8,
pub analysis_depth: EvidenceAnalysisDepth,
pub signals: Vec<EvidenceSignal>,
pub profiled_files: usize,
pub unlocked_recipe_tiers: Vec<String>,
pub unlock_suggestions: Vec<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable during the v1 beta.
Fields
grade: EvidenceGrademax_autonomous_tier: u8analysis_depth: EvidenceAnalysisDepthsignals: Vec<EvidenceSignal>profiled_files: usizeunlocked_recipe_tiers: Vec<String>unlock_suggestions: Vec<String>Trait Implementations
Sourceimpl Clone for EvidenceSummary
impl Clone for EvidenceSummary
Sourcefn clone(&self) -> EvidenceSummary
fn clone(&self) -> EvidenceSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvidenceSummary
impl Debug for EvidenceSummary
Sourceimpl<'de> Deserialize<'de> for EvidenceSummary
impl<'de> Deserialize<'de> for EvidenceSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvidenceSummary
impl JsonSchema for EvidenceSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvidenceSummary
impl RefUnwindSafe for EvidenceSummary
impl Send for EvidenceSummary
impl Sync for EvidenceSummary
impl Unpin for EvidenceSummary
impl UnsafeUnpin for EvidenceSummary
impl UnwindSafe for EvidenceSummary