pub struct EvolutionScorecard {
pub schema_version: String,
pub scorecard_id: String,
pub root: String,
pub target: Option<String>,
pub readiness: AutonomyReadiness,
pub map: CodebaseMap,
pub plan: RefactorPlan,
pub recipes: RecipeCatalog,
pub next_commands: Vec<String>,
pub artifact_path: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable during the v1 beta.
Fields
schema_version: Stringscorecard_id: Stringroot: Stringtarget: Option<String>readiness: AutonomyReadinessmap: CodebaseMapplan: RefactorPlanrecipes: RecipeCatalognext_commands: Vec<String>artifact_path: Option<String>Trait Implementations
Sourceimpl Clone for EvolutionScorecard
impl Clone for EvolutionScorecard
Sourcefn clone(&self) -> EvolutionScorecard
fn clone(&self) -> EvolutionScorecard
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvolutionScorecard
impl Debug for EvolutionScorecard
Sourceimpl<'de> Deserialize<'de> for EvolutionScorecard
impl<'de> Deserialize<'de> for EvolutionScorecard
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvolutionScorecard
impl JsonSchema for EvolutionScorecard
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvolutionScorecard
impl RefUnwindSafe for EvolutionScorecard
impl Send for EvolutionScorecard
impl Sync for EvolutionScorecard
impl Unpin for EvolutionScorecard
impl UnsafeUnpin for EvolutionScorecard
impl UnwindSafe for EvolutionScorecard