pub struct FailureSignal {
pub kind: FailureKind,
pub severity: u8,
pub evidence: String,
pub span_id: Option<String>,
}Expand description
Trace diagnosis records.
Fields
kind: FailureKindseverity: u8evidence: Stringspan_id: Option<String>Trait Implementations
Sourceimpl Clone for FailureSignal
impl Clone for FailureSignal
Sourcefn clone(&self) -> FailureSignal
fn clone(&self) -> FailureSignal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FailureSignal
impl Debug for FailureSignal
Sourceimpl<'de> Deserialize<'de> for FailureSignal
impl<'de> Deserialize<'de> for FailureSignal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FailureSignal
impl JsonSchema for FailureSignal
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FailureSignal
impl RefUnwindSafe for FailureSignal
impl Send for FailureSignal
impl Sync for FailureSignal
impl Unpin for FailureSignal
impl UnsafeUnpin for FailureSignal
impl UnwindSafe for FailureSignal