pub struct HardeningChangeSummary {
pub file: String,
pub strategy: String,
pub finding_ids: Vec<String>,
pub description: String,
pub old_hash: String,
pub new_hash: String,
}Expand description
Scoped Rust hardening engine for ordinary Rust modules. Unstable during the v1 beta.
Fields
file: Stringstrategy: Stringfinding_ids: Vec<String>description: Stringold_hash: Stringnew_hash: StringTrait Implementations
Sourceimpl Clone for HardeningChangeSummary
impl Clone for HardeningChangeSummary
Sourcefn clone(&self) -> HardeningChangeSummary
fn clone(&self) -> HardeningChangeSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HardeningChangeSummary
impl Debug for HardeningChangeSummary
Sourceimpl<'de> Deserialize<'de> for HardeningChangeSummary
impl<'de> Deserialize<'de> for HardeningChangeSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HardeningChangeSummary
impl JsonSchema for HardeningChangeSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HardeningChangeSummary
impl RefUnwindSafe for HardeningChangeSummary
impl Send for HardeningChangeSummary
impl Sync for HardeningChangeSummary
impl Unpin for HardeningChangeSummary
impl UnsafeUnpin for HardeningChangeSummary
impl UnwindSafe for HardeningChangeSummary