pub struct HardeningOutcome {
pub status: HardeningStatus,
pub isolated_validation_passed: bool,
pub applied: bool,
pub final_validation_passed: bool,
pub validation_commands: Vec<ValidationCommandRecord>,
pub final_validation_commands: Vec<ValidationCommandRecord>,
pub behavior_evaluation: Option<BehaviorEvalReport>,
pub final_behavior_evaluation: Option<BehaviorEvalReport>,
pub rollback_succeeded: Option<bool>,
pub rollback_error: Option<String>,
pub note: String,
}Expand description
Scoped Rust hardening engine for ordinary Rust modules. Unstable before 1.0.
Fields
status: HardeningStatusisolated_validation_passed: boolapplied: boolfinal_validation_passed: boolvalidation_commands: Vec<ValidationCommandRecord>final_validation_commands: Vec<ValidationCommandRecord>behavior_evaluation: Option<BehaviorEvalReport>final_behavior_evaluation: Option<BehaviorEvalReport>rollback_succeeded: Option<bool>rollback_error: Option<String>note: StringTrait Implementations
Sourceimpl Clone for HardeningOutcome
impl Clone for HardeningOutcome
Sourcefn clone(&self) -> HardeningOutcome
fn clone(&self) -> HardeningOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HardeningOutcome
impl Debug for HardeningOutcome
Sourceimpl<'de> Deserialize<'de> for HardeningOutcome
impl<'de> Deserialize<'de> for HardeningOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HardeningOutcome
impl JsonSchema for HardeningOutcome
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HardeningOutcome
impl RefUnwindSafe for HardeningOutcome
impl Send for HardeningOutcome
impl Sync for HardeningOutcome
impl Unpin for HardeningOutcome
impl UnsafeUnpin for HardeningOutcome
impl UnwindSafe for HardeningOutcome