pub struct HardeningPolicyRecord {
pub path: String,
pub hash: String,
pub rules: Vec<String>,
}Expand description
Scoped Rust hardening engine for ordinary Rust modules. Unstable before 1.0.
Fields
path: Stringhash: Stringrules: Vec<String>Trait Implementations
Sourceimpl Clone for HardeningPolicyRecord
impl Clone for HardeningPolicyRecord
Sourcefn clone(&self) -> HardeningPolicyRecord
fn clone(&self) -> HardeningPolicyRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HardeningPolicyRecord
impl Debug for HardeningPolicyRecord
Sourceimpl<'de> Deserialize<'de> for HardeningPolicyRecord
impl<'de> Deserialize<'de> for HardeningPolicyRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HardeningPolicyRecord
impl JsonSchema for HardeningPolicyRecord
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HardeningPolicyRecord
impl RefUnwindSafe for HardeningPolicyRecord
impl Send for HardeningPolicyRecord
impl Sync for HardeningPolicyRecord
impl Unpin for HardeningPolicyRecord
impl UnsafeUnpin for HardeningPolicyRecord
impl UnwindSafe for HardeningPolicyRecord