pub struct HookContext {
pub stage: HookStage,
pub agent_name: String,
pub edit_description: Option<String>,
pub patch_bytes: usize,
pub command: Option<String>,
pub validation_passed: Option<bool>,
pub score_delta: Option<f32>,
}Expand description
Built-in lifecycle hook primitives. These are unstable before 1.0.
Fields
stage: HookStageagent_name: Stringedit_description: Option<String>patch_bytes: usizecommand: Option<String>validation_passed: Option<bool>score_delta: Option<f32>Trait Implementations
Sourceimpl Clone for HookContext
impl Clone for HookContext
Sourcefn clone(&self) -> HookContext
fn clone(&self) -> HookContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookContext
impl Debug for HookContext
Sourceimpl<'de> Deserialize<'de> for HookContext
impl<'de> Deserialize<'de> for HookContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HookContext
impl JsonSchema for HookContext
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HookContext
impl RefUnwindSafe for HookContext
impl Send for HookContext
impl Sync for HookContext
impl Unpin for HookContext
impl UnsafeUnpin for HookContext
impl UnwindSafe for HookContext