pub struct HookPolicy {
pub max_patch_bytes: usize,
pub require_positive_delta: bool,
}Expand description
Built-in lifecycle hook primitives. These are unstable before 1.0.
Fields
max_patch_bytes: usizerequire_positive_delta: boolTrait Implementations
Sourceimpl Clone for HookPolicy
impl Clone for HookPolicy
Sourcefn clone(&self) -> HookPolicy
fn clone(&self) -> HookPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookPolicy
impl Debug for HookPolicy
Sourceimpl Default for HookPolicy
impl Default for HookPolicy
Sourceimpl<'de> Deserialize<'de> for HookPolicy
impl<'de> Deserialize<'de> for HookPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HookPolicy
impl JsonSchema for HookPolicy
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HookPolicy
impl RefUnwindSafe for HookPolicy
impl Send for HookPolicy
impl Sync for HookPolicy
impl Unpin for HookPolicy
impl UnsafeUnpin for HookPolicy
impl UnwindSafe for HookPolicy