pub struct MdxAgentContract {
pub schema_version: String,
pub product_version: String,
pub json_mode_contract: String,
pub mutation_contract: String,
pub commands: Vec<AgentCommandSpec>,
pub workflows: Vec<AgentWorkflow>,
pub artifact_globs: Vec<String>,
pub safety_rules: Vec<String>,
}Expand description
Agent-facing command contract for safe automation.
Fields
schema_version: Stringproduct_version: Stringjson_mode_contract: Stringmutation_contract: Stringcommands: Vec<AgentCommandSpec>workflows: Vec<AgentWorkflow>artifact_globs: Vec<String>safety_rules: Vec<String>Trait Implementations
Sourceimpl Clone for MdxAgentContract
impl Clone for MdxAgentContract
Sourcefn clone(&self) -> MdxAgentContract
fn clone(&self) -> MdxAgentContract
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MdxAgentContract
impl Debug for MdxAgentContract
Sourceimpl<'de> Deserialize<'de> for MdxAgentContract
impl<'de> Deserialize<'de> for MdxAgentContract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MdxAgentContract
impl JsonSchema for MdxAgentContract
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MdxAgentContract
impl RefUnwindSafe for MdxAgentContract
impl Send for MdxAgentContract
impl Sync for MdxAgentContract
impl Unpin for MdxAgentContract
impl UnsafeUnpin for MdxAgentContract
impl UnwindSafe for MdxAgentContract