pub struct ModelProvenance {
pub role: String,
pub provider: String,
pub model: String,
pub used: bool,
}Expand description
Optimizer entrypoint and run records. These are unstable before 1.0.
Fields
role: Stringprovider: Stringmodel: Stringused: boolTrait Implementations
Sourceimpl Clone for ModelProvenance
impl Clone for ModelProvenance
Sourcefn clone(&self) -> ModelProvenance
fn clone(&self) -> ModelProvenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelProvenance
impl Debug for ModelProvenance
Sourceimpl<'de> Deserialize<'de> for ModelProvenance
impl<'de> Deserialize<'de> for ModelProvenance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModelProvenance
impl JsonSchema for ModelProvenance
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModelProvenance
impl RefUnwindSafe for ModelProvenance
impl Send for ModelProvenance
impl Sync for ModelProvenance
impl Unpin for ModelProvenance
impl UnsafeUnpin for ModelProvenance
impl UnwindSafe for ModelProvenance