pub struct OptimizationRun {Show 33 fields
pub iteration: u32,
pub scores: Vec<f32>,
pub validated_changes: u32,
pub landed_changes: u32,
pub accepted_changes: u32,
pub notes: String,
pub candidates: Vec<Candidate>,
pub diff: Option<String>,
pub policy_hash: Option<String>,
pub dataset_version: Option<String>,
pub dataset_hash: Option<String>,
pub baseline_score: Option<f32>,
pub patched_score: Option<f32>,
pub score_delta: Option<f32>,
pub git_sha_before: Option<String>,
pub git_sha_after: Option<String>,
pub diff_hash: Option<String>,
pub working_tree_dirty_after: Option<bool>,
pub scorer: Option<String>,
pub validation_commands: Option<Vec<String>>,
pub validation_command_records: Vec<ValidationCommandRecord>,
pub final_validation_command_records: Vec<ValidationCommandRecord>,
pub trace_diagnosis: Vec<TraceDiagnosis>,
pub hook_decisions: Vec<HookDecision>,
pub ledger: Option<ExperimentLedger>,
pub holdout_score: Option<f32>,
pub budget: Option<OptimizationBudget>,
pub policy_path: Option<String>,
pub model: Option<ModelProvenance>,
pub rollback_succeeded: Option<bool>,
pub rollback_error: Option<String>,
pub candidate_timed_out: bool,
pub audit_packet: Option<AuditPacket>,
}Expand description
Optimizer entrypoint and run records. These are unstable before 1.0.
A single optimization experiment / iteration result.
Fields
iteration: u32scores: Vec<f32>validated_changes: u32Number of changes that were fully validated in isolation
landed_changes: u32Number of changes that were successfully landed on the real agent tree
accepted_changes: u32Number of changes that were accepted (landed + final validation + net-positive)
notes: Stringcandidates: Vec<Candidate>diff: Option<String>Optional unified diff of the last accepted change
policy_hash: Option<String>dataset_version: Option<String>dataset_hash: Option<String>baseline_score: Option<f32>patched_score: Option<f32>score_delta: Option<f32>git_sha_before: Option<String>git_sha_after: Option<String>diff_hash: Option<String>working_tree_dirty_after: Option<bool>scorer: Option<String>validation_commands: Option<Vec<String>>validation_command_records: Vec<ValidationCommandRecord>final_validation_command_records: Vec<ValidationCommandRecord>trace_diagnosis: Vec<TraceDiagnosis>hook_decisions: Vec<HookDecision>ledger: Option<ExperimentLedger>holdout_score: Option<f32>budget: Option<OptimizationBudget>policy_path: Option<String>model: Option<ModelProvenance>rollback_succeeded: Option<bool>rollback_error: Option<String>candidate_timed_out: boolaudit_packet: Option<AuditPacket>Versioned machine-readable evidence packet for an accepted change.