pub struct OptimizeConfig {
pub max_iterations: u32,
pub candidates_per_iteration: u32,
pub use_llm_judge: bool,
pub budget: OptimizationBudget,
pub hook_policy: HookPolicy,
pub review_before_apply: bool,
pub quiet: bool,
pub candidate_timeout: Duration,
}Expand description
Optimizer entrypoint and run records. These are unstable before 1.0.
Configuration for a single optimization run.
Fields
max_iterations: u32candidates_per_iteration: u32use_llm_judge: boolbudget: OptimizationBudgethook_policy: HookPolicyreview_before_apply: boolWhen true, the optimizer will print proposed changes and wait for confirmation before applying (Phase 4 review gate).
quiet: boolWhen true, suppress all human progress output (used for –json mode).
candidate_timeout: DurationTrait Implementations
Sourceimpl Clone for OptimizeConfig
impl Clone for OptimizeConfig
Sourcefn clone(&self) -> OptimizeConfig
fn clone(&self) -> OptimizeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OptimizeConfig
impl Debug for OptimizeConfig
Sourceimpl<'de> Deserialize<'de> for OptimizeConfig
impl<'de> Deserialize<'de> for OptimizeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OptimizeConfig
impl JsonSchema for OptimizeConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OptimizeConfig
impl RefUnwindSafe for OptimizeConfig
impl Send for OptimizeConfig
impl Sync for OptimizeConfig
impl Unpin for OptimizeConfig
impl UnsafeUnpin for OptimizeConfig
impl UnwindSafe for OptimizeConfig