pub struct PolicyFindingMatch {
pub finding_id: String,
pub rule_id: String,
pub category: PolicyCategory,
pub reason: String,
}Expand description
Scoped Rust hardening engine for ordinary Rust modules. Unstable before 1.0.
Fields
finding_id: Stringrule_id: Stringcategory: PolicyCategoryreason: StringTrait Implementations
Sourceimpl Clone for PolicyFindingMatch
impl Clone for PolicyFindingMatch
Sourcefn clone(&self) -> PolicyFindingMatch
fn clone(&self) -> PolicyFindingMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyFindingMatch
impl Debug for PolicyFindingMatch
Sourceimpl<'de> Deserialize<'de> for PolicyFindingMatch
impl<'de> Deserialize<'de> for PolicyFindingMatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PolicyFindingMatch
impl JsonSchema for PolicyFindingMatch
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PolicyFindingMatch
impl RefUnwindSafe for PolicyFindingMatch
impl Send for PolicyFindingMatch
impl Sync for PolicyFindingMatch
impl Unpin for PolicyFindingMatch
impl UnsafeUnpin for PolicyFindingMatch
impl UnwindSafe for PolicyFindingMatch