pub struct ProjectPolicy {
pub schema_version: String,
pub path: String,
pub hash: String,
pub rules: Vec<PolicyRule>,
}Expand description
Structured project policy records used by v0.4 hardening reports.
Fields
schema_version: Stringpath: Stringhash: Stringrules: Vec<PolicyRule>Trait Implementations
Sourceimpl Clone for ProjectPolicy
impl Clone for ProjectPolicy
Sourcefn clone(&self) -> ProjectPolicy
fn clone(&self) -> ProjectPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectPolicy
impl Debug for ProjectPolicy
Sourceimpl<'de> Deserialize<'de> for ProjectPolicy
impl<'de> Deserialize<'de> for ProjectPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProjectPolicy
impl JsonSchema for ProjectPolicy
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProjectPolicy
impl RefUnwindSafe for ProjectPolicy
impl Send for ProjectPolicy
impl Sync for ProjectPolicy
impl Unpin for ProjectPolicy
impl UnsafeUnpin for ProjectPolicy
impl UnwindSafe for ProjectPolicy