pub struct RecipeCatalog {
pub schema_version: String,
pub recipes: Vec<RecipeSpec>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
schema_version: Stringrecipes: Vec<RecipeSpec>Trait Implementations
Sourceimpl Clone for RecipeCatalog
impl Clone for RecipeCatalog
Sourcefn clone(&self) -> RecipeCatalog
fn clone(&self) -> RecipeCatalog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecipeCatalog
impl Debug for RecipeCatalog
Sourceimpl<'de> Deserialize<'de> for RecipeCatalog
impl<'de> Deserialize<'de> for RecipeCatalog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecipeCatalog
impl JsonSchema for RecipeCatalog
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecipeCatalog
impl RefUnwindSafe for RecipeCatalog
impl Send for RecipeCatalog
impl Sync for RecipeCatalog
impl Unpin for RecipeCatalog
impl UnsafeUnpin for RecipeCatalog
impl UnwindSafe for RecipeCatalog