pub struct RecipeSpec {
pub id: String,
pub recipe: RefactorRecipe,
pub tier: RecipeTier,
pub required_evidence: EvidenceGrade,
pub executable: bool,
pub risk: RefactorRiskLevel,
pub mutation_path: String,
pub description: String,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
id: Stringrecipe: RefactorRecipetier: RecipeTierrequired_evidence: EvidenceGradeexecutable: boolrisk: RefactorRiskLevelmutation_path: Stringdescription: StringTrait Implementations
Sourceimpl Clone for RecipeSpec
impl Clone for RecipeSpec
Sourcefn clone(&self) -> RecipeSpec
fn clone(&self) -> RecipeSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecipeSpec
impl Debug for RecipeSpec
Sourceimpl<'de> Deserialize<'de> for RecipeSpec
impl<'de> Deserialize<'de> for RecipeSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecipeSpec
impl JsonSchema for RecipeSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RecipeSpec
impl RefUnwindSafe for RecipeSpec
impl Send for RecipeSpec
impl Sync for RecipeSpec
impl Unpin for RecipeSpec
impl UnsafeUnpin for RecipeSpec
impl UnwindSafe for RecipeSpec