pub struct RefactorApplyRun {Show 14 fields
pub schema_version: String,
pub root: String,
pub plan_path: String,
pub plan_id: String,
pub plan_hash: String,
pub candidate_id: String,
pub candidate_hash: Option<String>,
pub mode: RefactorApplyMode,
pub status: RefactorApplyStatus,
pub public_api_impact_allowed: bool,
pub stale_files: Vec<StaleSourceFile>,
pub hardening_run: Option<HardeningRun>,
pub note: String,
pub artifact_path: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable during the v1 beta.
Fields
schema_version: Stringroot: Stringplan_path: Stringplan_id: Stringplan_hash: Stringcandidate_id: Stringcandidate_hash: Option<String>mode: RefactorApplyModestatus: RefactorApplyStatuspublic_api_impact_allowed: boolstale_files: Vec<StaleSourceFile>hardening_run: Option<HardeningRun>note: Stringartifact_path: Option<String>Trait Implementations
Sourceimpl Clone for RefactorApplyRun
impl Clone for RefactorApplyRun
Sourcefn clone(&self) -> RefactorApplyRun
fn clone(&self) -> RefactorApplyRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorApplyRun
impl Debug for RefactorApplyRun
Sourceimpl<'de> Deserialize<'de> for RefactorApplyRun
impl<'de> Deserialize<'de> for RefactorApplyRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorApplyRun
impl JsonSchema for RefactorApplyRun
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorApplyRun
impl RefUnwindSafe for RefactorApplyRun
impl Send for RefactorApplyRun
impl Sync for RefactorApplyRun
impl Unpin for RefactorApplyRun
impl UnsafeUnpin for RefactorApplyRun
impl UnwindSafe for RefactorApplyRun