pub struct RefactorBatchApplyRun {Show 15 fields
pub schema_version: String,
pub root: String,
pub plan_path: String,
pub plan_id: String,
pub plan_hash: String,
pub mode: RefactorApplyMode,
pub status: RefactorBatchApplyStatus,
pub public_api_impact_allowed: bool,
pub max_candidates: usize,
pub requested_candidates: usize,
pub executed_candidates: usize,
pub skipped_candidates: usize,
pub steps: Vec<RefactorBatchCandidateRun>,
pub note: String,
pub artifact_path: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable during the v1 beta.
Fields
schema_version: Stringroot: Stringplan_path: Stringplan_id: Stringplan_hash: Stringmode: RefactorApplyModestatus: RefactorBatchApplyStatuspublic_api_impact_allowed: boolmax_candidates: usizerequested_candidates: usizeexecuted_candidates: usizeskipped_candidates: usizesteps: Vec<RefactorBatchCandidateRun>note: Stringartifact_path: Option<String>Trait Implementations
Sourceimpl Clone for RefactorBatchApplyRun
impl Clone for RefactorBatchApplyRun
Sourcefn clone(&self) -> RefactorBatchApplyRun
fn clone(&self) -> RefactorBatchApplyRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorBatchApplyRun
impl Debug for RefactorBatchApplyRun
Sourceimpl<'de> Deserialize<'de> for RefactorBatchApplyRun
impl<'de> Deserialize<'de> for RefactorBatchApplyRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorBatchApplyRun
impl JsonSchema for RefactorBatchApplyRun
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorBatchApplyRun
impl RefUnwindSafe for RefactorBatchApplyRun
impl Send for RefactorBatchApplyRun
impl Sync for RefactorBatchApplyRun
impl Unpin for RefactorBatchApplyRun
impl UnsafeUnpin for RefactorBatchApplyRun
impl UnwindSafe for RefactorBatchApplyRun