pub struct RefactorBatchCandidateRun {
pub candidate_id: String,
pub candidate_hash: Option<String>,
pub file: String,
pub status: RefactorApplyStatus,
pub stale_file: Option<StaleSourceFile>,
pub hardening_run: Option<HardeningRun>,
pub note: String,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable during the v1 beta.
Fields
candidate_id: Stringcandidate_hash: Option<String>file: Stringstatus: RefactorApplyStatusstale_file: Option<StaleSourceFile>hardening_run: Option<HardeningRun>note: StringTrait Implementations
Sourceimpl Clone for RefactorBatchCandidateRun
impl Clone for RefactorBatchCandidateRun
Sourcefn clone(&self) -> RefactorBatchCandidateRun
fn clone(&self) -> RefactorBatchCandidateRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorBatchCandidateRun
impl Debug for RefactorBatchCandidateRun
Sourceimpl<'de> Deserialize<'de> for RefactorBatchCandidateRun
impl<'de> Deserialize<'de> for RefactorBatchCandidateRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorBatchCandidateRun
impl JsonSchema for RefactorBatchCandidateRun
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorBatchCandidateRun
impl RefUnwindSafe for RefactorBatchCandidateRun
impl Send for RefactorBatchCandidateRun
impl Sync for RefactorBatchCandidateRun
impl Unpin for RefactorBatchCandidateRun
impl UnsafeUnpin for RefactorBatchCandidateRun
impl UnwindSafe for RefactorBatchCandidateRun