pub struct RefactorCandidate {Show 15 fields
pub id: String,
pub candidate_hash: String,
pub recipe: RefactorRecipe,
pub title: String,
pub rationale: String,
pub file: String,
pub line: usize,
pub risk: RefactorRiskLevel,
pub status: RefactorCandidateStatus,
pub tier: RecipeTier,
pub required_evidence: EvidenceGrade,
pub evidence_satisfied: bool,
pub public_api_impact: bool,
pub apply_command: Option<String>,
pub required_gates: Vec<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
id: Stringcandidate_hash: Stringrecipe: RefactorRecipetitle: Stringrationale: Stringfile: Stringline: usizerisk: RefactorRiskLevelstatus: RefactorCandidateStatustier: RecipeTierrequired_evidence: EvidenceGradeevidence_satisfied: boolpublic_api_impact: boolapply_command: Option<String>required_gates: Vec<String>Trait Implementations
Sourceimpl Clone for RefactorCandidate
impl Clone for RefactorCandidate
Sourcefn clone(&self) -> RefactorCandidate
fn clone(&self) -> RefactorCandidate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorCandidate
impl Debug for RefactorCandidate
Sourceimpl<'de> Deserialize<'de> for RefactorCandidate
impl<'de> Deserialize<'de> for RefactorCandidate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorCandidate
impl JsonSchema for RefactorCandidate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorCandidate
impl RefUnwindSafe for RefactorCandidate
impl Send for RefactorCandidate
impl Sync for RefactorCandidate
impl Unpin for RefactorCandidate
impl UnsafeUnpin for RefactorCandidate
impl UnwindSafe for RefactorCandidate