pub struct RefactorImpactSummary {
pub files_scanned: usize,
pub public_item_count: usize,
pub public_files: usize,
pub module_edge_count: usize,
pub patchable_hardening_changes: usize,
pub review_only_findings: usize,
pub oversized_files: usize,
pub oversized_functions: usize,
pub risk_level: RefactorRiskLevel,
}Expand description
Plan-first refactor records used by v0.5. Unstable before 1.0.
Fields
files_scanned: usizepublic_item_count: usizepublic_files: usizemodule_edge_count: usizepatchable_hardening_changes: usizereview_only_findings: usizeoversized_files: usizeoversized_functions: usizerisk_level: RefactorRiskLevelTrait Implementations
Sourceimpl Clone for RefactorImpactSummary
impl Clone for RefactorImpactSummary
Sourcefn clone(&self) -> RefactorImpactSummary
fn clone(&self) -> RefactorImpactSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorImpactSummary
impl Debug for RefactorImpactSummary
Sourceimpl<'de> Deserialize<'de> for RefactorImpactSummary
impl<'de> Deserialize<'de> for RefactorImpactSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorImpactSummary
impl JsonSchema for RefactorImpactSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorImpactSummary
impl RefUnwindSafe for RefactorImpactSummary
impl Send for RefactorImpactSummary
impl Sync for RefactorImpactSummary
impl Unpin for RefactorImpactSummary
impl UnsafeUnpin for RefactorImpactSummary
impl UnwindSafe for RefactorImpactSummary