pub struct RefactorPlan {Show 17 fields
pub schema_version: String,
pub plan_id: String,
pub plan_hash: String,
pub root: String,
pub target: Option<String>,
pub workspace: WorkspaceSummary,
pub policy: Option<ProjectPolicy>,
pub behavior_spec: Option<String>,
pub evidence: EvidenceSummary,
pub impact: RefactorImpactSummary,
pub source_snapshots: Vec<SourceSnapshot>,
pub files: Vec<RefactorFileSummary>,
pub module_edges: Vec<ModuleEdge>,
pub candidates: Vec<RefactorCandidate>,
pub required_gates: Vec<String>,
pub non_goals: Vec<String>,
pub artifact_path: Option<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
schema_version: Stringplan_id: Stringplan_hash: Stringroot: Stringtarget: Option<String>workspace: WorkspaceSummarypolicy: Option<ProjectPolicy>behavior_spec: Option<String>evidence: EvidenceSummaryimpact: RefactorImpactSummarysource_snapshots: Vec<SourceSnapshot>files: Vec<RefactorFileSummary>module_edges: Vec<ModuleEdge>candidates: Vec<RefactorCandidate>required_gates: Vec<String>non_goals: Vec<String>artifact_path: Option<String>Trait Implementations
Sourceimpl Clone for RefactorPlan
impl Clone for RefactorPlan
Sourcefn clone(&self) -> RefactorPlan
fn clone(&self) -> RefactorPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefactorPlan
impl Debug for RefactorPlan
Sourceimpl<'de> Deserialize<'de> for RefactorPlan
impl<'de> Deserialize<'de> for RefactorPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefactorPlan
impl JsonSchema for RefactorPlan
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefactorPlan
impl RefUnwindSafe for RefactorPlan
impl Send for RefactorPlan
impl Sync for RefactorPlan
impl Unpin for RefactorPlan
impl UnsafeUnpin for RefactorPlan
impl UnwindSafe for RefactorPlan