pub struct RegisteredAgent {
pub name: String,
pub path: PathBuf,
pub contract: AgentContract,
pub registered_at: String,
}Expand description
Agent registry types used by CLI commands. Represents a registered agent
Fields
name: Stringpath: PathBufcontract: AgentContractregistered_at: StringTrait Implementations
Sourceimpl Clone for RegisteredAgent
impl Clone for RegisteredAgent
Sourcefn clone(&self) -> RegisteredAgent
fn clone(&self) -> RegisteredAgent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisteredAgent
impl Debug for RegisteredAgent
Sourceimpl<'de> Deserialize<'de> for RegisteredAgent
impl<'de> Deserialize<'de> for RegisteredAgent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RegisteredAgent
impl JsonSchema for RegisteredAgent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RegisteredAgent
impl RefUnwindSafe for RegisteredAgent
impl Send for RegisteredAgent
impl Sync for RegisteredAgent
impl Unpin for RegisteredAgent
impl UnsafeUnpin for RegisteredAgent
impl UnwindSafe for RegisteredAgent