pub struct SafetyRejection {
pub kind: SafetyRejectionKind,
pub message: String,
}Expand description
Candidate safety pipeline. Direct use is unstable before 1.0.
Fields
kind: SafetyRejectionKindmessage: StringTrait Implementations
Sourceimpl Clone for SafetyRejection
impl Clone for SafetyRejection
Sourcefn clone(&self) -> SafetyRejection
fn clone(&self) -> SafetyRejection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SafetyRejection
impl Debug for SafetyRejection
Sourceimpl<'de> Deserialize<'de> for SafetyRejection
impl<'de> Deserialize<'de> for SafetyRejection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SafetyRejection
impl JsonSchema for SafetyRejection
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SafetyRejection
impl RefUnwindSafe for SafetyRejection
impl Send for SafetyRejection
impl Sync for SafetyRejection
impl Unpin for SafetyRejection
impl UnsafeUnpin for SafetyRejection
impl UnwindSafe for SafetyRejection