pub struct ScoreProvenance {
pub baseline_score: f32,
pub patched_score: f32,
pub score_delta: f32,
pub holdout_score: Option<f32>,
}Expand description
Optimizer entrypoint and run records. These are unstable during the v1 beta. Score evidence for the accepted change.
Fields
baseline_score: f32patched_score: f32score_delta: f32holdout_score: Option<f32>Trait Implementations
Sourceimpl Clone for ScoreProvenance
impl Clone for ScoreProvenance
Sourcefn clone(&self) -> ScoreProvenance
fn clone(&self) -> ScoreProvenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScoreProvenance
impl Debug for ScoreProvenance
Sourceimpl<'de> Deserialize<'de> for ScoreProvenance
impl<'de> Deserialize<'de> for ScoreProvenance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScoreProvenance
impl JsonSchema for ScoreProvenance
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScoreProvenance
impl RefUnwindSafe for ScoreProvenance
impl Send for ScoreProvenance
impl Sync for ScoreProvenance
impl Unpin for ScoreProvenance
impl UnsafeUnpin for ScoreProvenance
impl UnwindSafe for ScoreProvenance