pub struct SecurityPostureSummary {
pub score: u8,
pub high: usize,
pub medium: usize,
pub low: usize,
pub info: usize,
pub top_findings: Vec<String>,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
score: u8high: usizemedium: usizelow: usizeinfo: usizetop_findings: Vec<String>Trait Implementations
Sourceimpl Clone for SecurityPostureSummary
impl Clone for SecurityPostureSummary
Sourcefn clone(&self) -> SecurityPostureSummary
fn clone(&self) -> SecurityPostureSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecurityPostureSummary
impl Debug for SecurityPostureSummary
Sourceimpl Default for SecurityPostureSummary
impl Default for SecurityPostureSummary
Sourceimpl<'de> Deserialize<'de> for SecurityPostureSummary
impl<'de> Deserialize<'de> for SecurityPostureSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SecurityPostureSummary
impl JsonSchema for SecurityPostureSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SecurityPostureSummary
impl RefUnwindSafe for SecurityPostureSummary
impl Send for SecurityPostureSummary
impl Sync for SecurityPostureSummary
impl Unpin for SecurityPostureSummary
impl UnsafeUnpin for SecurityPostureSummary
impl UnwindSafe for SecurityPostureSummary