pub struct SourceSnapshot {
pub file: String,
pub hash: String,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
file: Stringhash: StringTrait Implementations
Sourceimpl Clone for SourceSnapshot
impl Clone for SourceSnapshot
Sourcefn clone(&self) -> SourceSnapshot
fn clone(&self) -> SourceSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceSnapshot
impl Debug for SourceSnapshot
Sourceimpl<'de> Deserialize<'de> for SourceSnapshot
impl<'de> Deserialize<'de> for SourceSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SourceSnapshot
impl JsonSchema for SourceSnapshot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SourceSnapshot
impl RefUnwindSafe for SourceSnapshot
impl Send for SourceSnapshot
impl Sync for SourceSnapshot
impl Unpin for SourceSnapshot
impl UnsafeUnpin for SourceSnapshot
impl UnwindSafe for SourceSnapshot