pub struct StaleSourceFile {
pub file: String,
pub expected_hash: String,
pub actual_hash: String,
}Expand description
Plan-first refactor and autonomous orchestration records. Unstable before 1.0.
Fields
file: Stringexpected_hash: Stringactual_hash: StringTrait Implementations
Sourceimpl Clone for StaleSourceFile
impl Clone for StaleSourceFile
Sourcefn clone(&self) -> StaleSourceFile
fn clone(&self) -> StaleSourceFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StaleSourceFile
impl Debug for StaleSourceFile
Sourceimpl<'de> Deserialize<'de> for StaleSourceFile
impl<'de> Deserialize<'de> for StaleSourceFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StaleSourceFile
impl JsonSchema for StaleSourceFile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StaleSourceFile
impl RefUnwindSafe for StaleSourceFile
impl Send for StaleSourceFile
impl Sync for StaleSourceFile
impl Unpin for StaleSourceFile
impl UnsafeUnpin for StaleSourceFile
impl UnwindSafe for StaleSourceFile