pub struct WorkspaceSummary {
pub cargo_metadata_available: bool,
pub package_count: usize,
pub package_names: Vec<String>,
}Expand description
Scoped Rust hardening engine for ordinary Rust modules. Unstable before 1.0.
Fields
cargo_metadata_available: boolpackage_count: usizepackage_names: Vec<String>Trait Implementations
Sourceimpl Clone for WorkspaceSummary
impl Clone for WorkspaceSummary
Sourcefn clone(&self) -> WorkspaceSummary
fn clone(&self) -> WorkspaceSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspaceSummary
impl Debug for WorkspaceSummary
Sourceimpl<'de> Deserialize<'de> for WorkspaceSummary
impl<'de> Deserialize<'de> for WorkspaceSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkspaceSummary
impl JsonSchema for WorkspaceSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkspaceSummary
impl RefUnwindSafe for WorkspaceSummary
impl Send for WorkspaceSummary
impl Sync for WorkspaceSummary
impl Unpin for WorkspaceSummary
impl UnsafeUnpin for WorkspaceSummary
impl UnwindSafe for WorkspaceSummary